@@ -9,18 +9,21 @@ import publication
 import typing_extensions
 
 import aws_cdk.aws_certificatemanager._jsii
+import aws_cdk.aws_cloudwatch._jsii
+import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
+import aws_cdk.aws_ssm._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-cloudfront",
-    "1.75.0",
+    "1.77.0",
     __name__[0:-6],
-    "aws-cloudfront@1.75.0.jsii.tgz",
+    "aws-cloudfront@1.77.0.jsii.tgz",
 )
 
 __all__ = [
